==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicOptionPaneUI__243.h <==
// final class javax.swing.plaf.basic.BasicOptionPaneUI$3

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class fe1fd5d07dda552 javax_swing_plaf_basic_BasicOptionPaneUI__243
// @dep_class 7173f5e939a87bd6 javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon

// header file dependencies
// @dep_header javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon

#include "javax/swing/plaf/basic/BasicOptionPaneUI__24MessageIcon.h"

#ifndef _JC_javax_swing_plaf_basic_BasicOptionPaneUI__243_H_
#define _JC_javax_swing_plaf_basic_BasicOptionPaneUI__243_H_

// Forward structure declarations
struct _jc_java_awt_Component$object;
struct _jc_java_awt_Graphics$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__243$sub_refs	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__243$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__243$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__243$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__243$refs	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__243$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__243$nonrefs	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__243$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__243$object	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__243$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__243$vmethods	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__243$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__243$vtable	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__243$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__243$vtype	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__243$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicOptionPaneUI__243$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__243$object *);

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicOptionPaneUI__243$method$paintIcon$ec942e304ba768a4(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__243$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Graphics$object *, jint, jint);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicOptionPaneUI__243$method_info$paintIcon$ec942e304ba768a4;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__243$vmethods {
	void	(*paintIcon$ec942e304ba768a4)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__243$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Graphics$object *, jint, jint);
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__243$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$vmethods	javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon;
	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__243$vmethods	javax_swing_plaf_basic_BasicOptionPaneUI__243;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__243$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__243$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__243$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__243$refs {
    _jc_javax_swing_plaf_basic_BasicOptionPaneUI__243$sub_refs	javax_swing_plaf_basic_BasicOptionPaneUI__243;
    _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$sub_refs	javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__243$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__243$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$sub_nonrefs	javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon;
    _jc_javax_swing_plaf_basic_BasicOptionPaneUI__243$sub_nonrefs	javax_swing_plaf_basic_BasicOptionPaneUI__243;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__243$object {
	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__243$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__243$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__243$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicOptionPaneUI__243$vtype _jc_javax_swing_plaf_basic_BasicOptionPaneUI__243$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicOptionPaneUI__243, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicOptionPaneUI__243$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicOptionPaneUI__243_H_ */

==> jc-1.4.5.tar.gz: javax/swing/plaf/basic/BasicOptionPaneUI__243.h <==
// final class javax.swing.plaf.basic.BasicOptionPaneUI$3

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 34e92e4a2a9806d7 javax_swing_plaf_basic_BasicOptionPaneUI__243
// @dep_class dfbd93626158fee3 javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon

// header file dependencies
// @dep_header javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon

#include "javax/swing/plaf/basic/BasicOptionPaneUI__24MessageIcon.h"

#ifndef _JC_javax_swing_plaf_basic_BasicOptionPaneUI__243_H_
#define _JC_javax_swing_plaf_basic_BasicOptionPaneUI__243_H_

// Forward structure declarations
struct _jc_java_awt_Component$object;
struct _jc_java_awt_Graphics$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__243$sub_refs	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__243$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__243$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__243$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__243$refs	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__243$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__243$nonrefs	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__243$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__243$object	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__243$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__243$vmethods	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__243$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__243$vtable	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__243$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__243$vtype	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__243$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicOptionPaneUI__243$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__243$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicOptionPaneUI__243$method$paintIcon$ec942e304ba768a4(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__243$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Graphics$object *, jint, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicOptionPaneUI__243$method_info$paintIcon$ec942e304ba768a4;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__243$vmethods {
	void	(*paintIcon$ec942e304ba768a4)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__243$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Graphics$object *, jint, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__243$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$vmethods	javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon;
	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__243$vmethods	javax_swing_plaf_basic_BasicOptionPaneUI__243;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__243$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__243$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__243$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__243$refs {
    _jc_javax_swing_plaf_basic_BasicOptionPaneUI__243$sub_refs	javax_swing_plaf_basic_BasicOptionPaneUI__243;
    _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$sub_refs	javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__243$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__243$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$sub_nonrefs	javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon;
    _jc_javax_swing_plaf_basic_BasicOptionPaneUI__243$sub_nonrefs	javax_swing_plaf_basic_BasicOptionPaneUI__243;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__243$object {
	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__243$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__243$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__243$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicOptionPaneUI__243$vtype _jc_javax_swing_plaf_basic_BasicOptionPaneUI__243$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicOptionPaneUI__243, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicOptionPaneUI__243$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicOptionPaneUI__243_H_ */
